==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1GroupVersionForDiscoveryFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1GroupVersionForDiscoveryFluentImpl<A extends V1GroupVersionForDiscoveryFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1GroupVersionForDiscoveryFluent<A>{

    private String groupVersion;
    private String version;

    public V1GroupVersionForDiscoveryFluentImpl(){
    }
    public V1GroupVersionForDiscoveryFluentImpl(V1GroupVersionForDiscovery instance){
            this.withGroupVersion(instance.getGroupVersion());

            this.withVersion(instance.getVersion());

    }

    public String getGroupVersion(){
            return this.groupVersion;
    }

    public A withGroupVersion(String groupVersion){
            this.groupVersion=groupVersion; return (A) this;
    }

    public Boolean hasGroupVersion(){
            return this.groupVersion != null;
    }

    public String getVersion(){
            return this.version;
    }

    public A withVersion(String version){
            this.version=version; return (A) this;
    }

    public Boolean hasVersion(){
            return this.version != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1GroupVersionForDiscoveryFluentImpl that = (V1GroupVersionForDiscoveryFluentImpl) o;
            if (groupVersion != null ? !groupVersion.equals(that.groupVersion) :that.groupVersion != null) return false;
            if (version != null ? !version.equals(that.version) :that.version != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1GroupVersionForDiscoveryFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1GroupVersionForDiscoveryFluentImpl<A extends V1GroupVersionForDiscoveryFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1GroupVersionForDiscoveryFluent<A>{

    private String groupVersion;
    private String version;

    public V1GroupVersionForDiscoveryFluentImpl(){
    }
    public V1GroupVersionForDiscoveryFluentImpl(V1GroupVersionForDiscovery instance){
            this.withGroupVersion(instance.getGroupVersion());

            this.withVersion(instance.getVersion());

    }

    public String getGroupVersion(){
            return this.groupVersion;
    }

    public A withGroupVersion(String groupVersion){
            this.groupVersion=groupVersion; return (A) this;
    }

    public Boolean hasGroupVersion(){
            return this.groupVersion != null;
    }

    public A withNewGroupVersion(String arg1){
            return (A)withGroupVersion(new String(arg1));
    }

    public A withNewGroupVersion(StringBuilder arg1){
            return (A)withGroupVersion(new String(arg1));
    }

    public A withNewGroupVersion(StringBuffer arg1){
            return (A)withGroupVersion(new String(arg1));
    }

    public String getVersion(){
            return this.version;
    }

    public A withVersion(String version){
            this.version=version; return (A) this;
    }

    public Boolean hasVersion(){
            return this.version != null;
    }

    public A withNewVersion(String arg1){
            return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuilder arg1){
            return (A)withVersion(new String(arg1));
    }

    public A withNewVersion(StringBuffer arg1){
            return (A)withVersion(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1GroupVersionForDiscoveryFluentImpl that = (V1GroupVersionForDiscoveryFluentImpl) o;
            if (groupVersion != null ? !groupVersion.equals(that.groupVersion) :that.groupVersion != null) return false;
            if (version != null ? !version.equals(that.version) :that.version != null) return false;
            return true;
    }




}
